==> logicFS_1.14.0.zip: logicFS/doc/logicFS.R <==
###################################################
### chunk number 1: 
###################################################
library(logicFS)


###################################################
### chunk number 2: 
###################################################
data(data.logicfs)


###################################################
### chunk number 3: 
###################################################
bin.snps<-make.snp.dummy(data.logicfs)


###################################################
### chunk number 4: 
###################################################
my.anneal<-logreg.anneal.control(start=2, end=-2, iter=10000)


###################################################
### chunk number 5: 
###################################################
log.out<-logicFS(bin.snps, cl.logicfs, B=20, nleaves=10, rand=123, anneal.control=my.anneal)


###################################################
### chunk number 6: 
###################################################
log.out


###################################################
### chunk number 7:  eval=FALSE
###################################################
## plot(log.out)


###################################################
### chunk number 8: 
###################################################
bag.out<-logic.bagging(bin.snps, cl.logicfs, B=20, nleaves=10, rand=123, anneal.control=my.anneal)
bag.out


###################################################
### chunk number 9: 
###################################################
bag.out$vim


###################################################
### chunk number 10: 
###################################################
cl.preds<-predict(bag.out,bin.snps)


###################################################
### chunk number 11: 
###################################################
mean(cl.preds!=cl.logicfs)

==> logicFS_1.20.0.zip: logicFS/doc/logicFS.R <==
###################################################
### chunk number 1: 
###################################################
#line 57 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
library(logicFS)


###################################################
### chunk number 2: 
###################################################
#line 63 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
data(data.logicfs)


###################################################
### chunk number 3: 
###################################################
#line 95 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
bin.snps<-make.snp.dummy(data.logicfs)


###################################################
### chunk number 4: 
###################################################
#line 108 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
my.anneal<-logreg.anneal.control(start=2, end=-2, iter=10000)


###################################################
### chunk number 5: 
###################################################
#line 115 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
log.out<-logicFS(bin.snps, cl.logicfs, B=20, nleaves=10, rand=123, anneal.control=my.anneal)


###################################################
### chunk number 6: 
###################################################
#line 125 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
log.out


###################################################
### chunk number 7:  eval=FALSE
###################################################
## #line 137 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
## plot(log.out)


###################################################
### chunk number 8: 
###################################################
#line 168 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
bag.out<-logic.bagging(bin.snps, cl.logicfs, B=20, nleaves=10, rand=123, anneal.control=my.anneal)
bag.out


###################################################
### chunk number 9: 
###################################################
#line 177 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
bag.out$vim


###################################################
### chunk number 10: 
###################################################
#line 186 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
cl.preds<-predict(bag.out,bin.snps)


###################################################
### chunk number 11: 
###################################################
#line 193 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpA2ygbW/R.INSTALL3b17acd/logicFS/inst/doc/logicFS.Rnw"
mean(cl.preds!=cl.logicfs)
